import datetime

from mongoengine import *

from .data import CITTSiffness
from .material import Material


class CyclicIndirectTensileTest(Document):

    date = DateTimeField(default=datetime.datetime.now,
                         wtf_options={"render_kw": {
                             "step": "60"
                         }})

    standard = StringField(default='TP Asphalt Teil 24')

    lab = StringField(default='TU Dresden', required=True)
    auditor = StringField(default=None)
    machine = StringField(default=None)

    filehash = StringField(required=True)

    project = StringField(required=True)
    workpackage = StringField()
    material = ReferenceField(Material, required=True)

    meta = {
        'allow_inheritance': True,
        'index_opts': {},
        'index_background': True,
        'index_cls': False,
        'auto_create_index': True,
        'collection': 'citt',
    }


class CITTSiffness(CyclicIndirectTensileTest):

    #metadata
    f_set = FloatField()
    sigma_set = FloatField()
    T_set = FloatField()

    N_from = IntField()
    N_to = IntField()

    data = LazyReferenceField(CITTSiffness,
                              required=True,
                              reverse_delete_rule=CASCADE)

    #results
    stiffness = FloatField()
    nu = FloatField()
    phase = FloatField()
    #fit parameter
    ## F
    F_amp = FloatField()
    F_freq = FloatField()
    F_phase = FloatField()
    F_offset = FloatField()
    F_slope = FloatField()
    F_r2 = FloatField()
    ## S1
    s_hor_1_amp = FloatField()
    s_hor_1_freq = FloatField()
    s_hor_1_phase = FloatField()
    s_hor_1_offset = FloatField()
    s_hor_1_slope = FloatField()
    s_hor_1_r2 = FloatField()
    ## S2
    s_hor_2_amp = FloatField()
    s_hor_2_freq = FloatField()
    s_hor_2_phase = FloatField()
    s_hor_2_offset = FloatField()
    s_hor_2_slope = FloatField()
    s_hor_2_r2 = FloatField()
    ## S-Sum
    s_hor_amp = FloatField()
    s_hor_freq = FloatField()
    s_hor_phase = FloatField()
    s_hor_offset = FloatField()
    s_hor_slope = FloatField()
    s_hor_r2 = FloatField()
